"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cli = void 0;
const getopts_1 = __importDefault(require("getopts"));
const generate_1 = require("./commands/generate");
const help = `
Usage:

next-typed-path generate <output-path>   Generate routes
  --dir, -d         Path to pages directory (default: src/pages)
  --name, -n        Variable name of exported routes object (default: routes)
  --defaultExport   Default export routes object (default: false)
`.trim();
const cli = async () => {
    const { _: [command, ...args], dir, name, defaultExport, } = getopts_1.default(process.argv.slice(2), {
        alias: { dir: 'd', name: 'n' },
        boolean: ['defaultExport'],
        default: { dir: 'src/pages', name: 'routes' },
    });
    switch (command) {
        case 'generate':
            if (!args[0]) {
                console.error('Output path must be specified');
                process.exit(1);
            }
            void generate_1.generate({ output: args[0], dir, name, defaultExport });
            break;
        case '--help':
            console.log(help);
            break;
        default:
            console.log(help);
            process.exit(1);
    }
};
exports.cli = cli;
